API docs for “spamfighter.api”

# Package s.api

Part of spamfighter View Source

Набор команд, составляющих API СпамоБорца (`sf.*`).

Package | domain | Набор команд СпамоБорца `sf.domain.*`.
Package | info | Набор команд СпамоБорца `sf.info.*`.
Package | message | Набор команд СпамоБорца `sf.message.*`.
Package | model | Набор команд СпамоБорца `sf.model.*`.

From the __init__.py module:

Function | loadCommands | Загрузить все команды СпамоБорца.

def loadCommands(): (source)
Загрузить все команды СпамоБорца.